## Utility libraries

These are utility libraries that are available for external use:

- [SLIP-0032](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/slip32.md)
- [Address encoding/decoding](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/addr.md)
- [Bitcoin Cash address converter](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/bch_addr_converter.md)
- [Solana SPL](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/solana_spl.md)
- [bech32](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/bech32.md)
- [base58](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/base58.md)
- [ss58](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/ss58.md)
- [WIF](https://github.com/ebellocchia/bip_utils/tree/master/readme/utility/wif.md)
